/*
 * Copyright (C) 2011 Panasonic Corporation
 * All Rights Reserved.
 *
 * SPDX-License-Identifier:	GPL-2.0+
 */

#include <common.h>
#include <asm/arch/cacheflush.h>

#if !(defined(CONFIG_SYS_ICACHE_OFF) && \
      defined(CONFIG_SYS_DCACHE_OFF) && \
      defined(CONFIG_SYS_L2CACHE_OFF))
static unsigned long mn_addr_trans(unsigned long vaddr)
{
#ifdef CONFIG_USE_IRQ
	unsigned long flags;
#endif /* CONFIG_USE_IRQ */
	unsigned long ret;

#ifdef CONFIG_USE_IRQ
	local_irq_save(flags);
#endif /* CONFIG_USE_IRQ */

	__asm__ __volatile__(
"	mcr	p15, 0, %1, c7, c8, 0\n"
"	mrc	p15, 0, %0, c7, c4, 0\n"
"	tst	%0, #1\n"
"	movne	%0, #0\n"
	: "=r" (ret)
	: "r" (vaddr)
	: "cc");

#ifdef CONFIG_USE_IRQ
	local_irq_restore(flags);
#endif /* CONFIG_USE_IRQ */

	ret = (ret & PAGE_MASK) | (vaddr & ~PAGE_MASK);
	return ret;
}
#endif

#if !(defined(CONFIG_SYS_ICACHE_OFF) && defined(CONFIG_SYS_DCACHE_OFF))
static void vaddr_purge_L1cache(unsigned long start, unsigned long size, int flag)
{
	switch (flag) {
	case PURGE_CACHE_D_PURGE_INV:
		flush_L1_dcache_range(start, start + size);
		break;
	case PURGE_CACHE_D_INV:
	case PURGE_CACHE_D_INV_BEFORE_DMA:
	case PURGE_CACHE_D_INV_AFTER_DMA:
		invalidate_L1_dcache_range(start, start + size);
		break;
	default: /* Not support other flag in u-boot. */
		break;
	}
	return;
}
#else
#define vaddr_purge_L1cache(start, size, flag) do {} while(0)
#endif

#ifndef CONFIG_SYS_L2CACHE_OFF
static void purge_L2cache(unsigned long start, unsigned long size, int flag)
{
	unsigned long end = start + size;
	if (end <= start)	return;

	switch (flag) {
	case PURGE_CACHE_D_PURGE_INV:
		flush_L2_dcache_range(start, end);
		break;
	case PURGE_CACHE_D_INV:
	case PURGE_CACHE_D_INV_BEFORE_DMA:
	case PURGE_CACHE_D_INV_AFTER_DMA:
		invalidate_L2_dcache_range(start, end);
		break;
	default: /* Not support other flag in u-boot. */
		break;
	}
}
#else /* !CONFIG_SYS_L2CACHE_OFF */
#define purge_L2cache(vstart, size, flag) do {} while(0)
#endif /* !CONFIG_SYS_L2CACHE_OFF */

#define need_flush_L1cache_first(flag) \
	(flag != PURGE_CACHE_D_INV_AFTER_DMA)

#define need_flush_L1cache_last(flag) \
	(/*flag != PURGE_CACHE_D_PURGE*/ 1 \
	&& /*flag != PURGE_CACHE_ID_SYNC*/ 1 \
	&& /*flag != PURGE_CACHE_I_INV*/ 1 \
	&& flag != PURGE_CACHE_D_INV_BEFORE_DMA)

void vaddr_purge_cache(unsigned long vstart, unsigned long size, int flag)
{
#if !(defined(CONFIG_SYS_ICACHE_OFF) && \
      defined(CONFIG_SYS_DCACHE_OFF) && \
      defined(CONFIG_SYS_L2CACHE_OFF))
	unsigned long i, w, paddr;

	for (i = 0; i < size; i += w) {
		w = PAGE_SIZE - ((vstart + i) & ~PAGE_MASK);
		if ((size - i) < w) {
			w = size - i;
		}
		paddr = mn_addr_trans(vstart + i);
		if (paddr != 0) {
#ifndef CONFIG_SYS_L2CACHE_OFF
			if (need_flush_L1cache_first(flag)) {
				vaddr_purge_L1cache(vstart + i, w, flag);
			}
			purge_L2cache(paddr, w, flag);
			if (need_flush_L1cache_last(flag)) {
				vaddr_purge_L1cache(vstart + i, w, flag);
			}
#else /* !CONFIG_SYS_L2CACHE_OFF */
			vaddr_purge_L1cache(vstart + i, w, flag);
#endif /* !CONFIG_SYS_L2CACHE_OFF */
		}
	}
#endif /* !(CONFIG_SYS_ICACHE_OFF && CONFIG_SYS_DCACHE_OFF && \
            CONFIG_SYS_L2CACHE_OFF) */
}

#ifndef CONFIG_SYS_DCACHE_OFF
void enable_caches(void)
{
	/* Enable D-cache. I-cache is already enabled in start.S */
	dcache_enable();
}
#endif
