/*
 * Copyright (C) 2010 Panasonic Corporation
 * All Rights Reserved.
 *
 * SPDX-License-Identifier:	GPL-2.0+
 */

#include <common.h>
#include <asm/arch/timer-regs.h>

DECLARE_GLOBAL_DATA_PTR;

#define timestamp	(gd->arch.tbl)
#define lastinc		(gd->arch.lastinc)

#define TIMER_LOAD_VAL 0xFFFFFFFF
#define MASK_16 0xFFFF

#define get_counter()	(~(*TM45BC))

int timer_init(void)
{
	*TM5BR = (TIMER_LOAD_VAL >> 16) & MASK_16;
	*TM5MD = (TM5MD_INIT_COUNTER | TM5MD_SRC_TM4CASCADE);
	*TM4BR = (TIMER_LOAD_VAL & MASK_16);
	*TM4MD = TM4MD_INIT_COUNTER;
	*TM5MD = (TM5MD_COUNT_ENABLE | TM5MD_SRC_TM4CASCADE);
	*TM4MD = (TM4MD_COUNT_ENABLE);

	return 0;
}

/*
 * timer without interrupts
 */
void reset_timer(void)
{
	reset_timer_masked();
}

ulong get_timer (ulong base)
{
	return get_timer_masked() - base;
}

void set_timer (ulong t)
{
	timestamp = t;
}

/* delay x useconds */
void __udelay (unsigned long usec)
{
	long tmo = usec * ((IOCLK / 1000) / 1000);
	unsigned long now, last = get_counter();

	while (tmo > 0) {
		now = get_counter();
		if (last > now) {/* count up timer overflow */
			tmo -= TIMER_LOAD_VAL - last + now;
		} else {
			tmo -= now - last;
		}
		last = now;
	}
	return;
}

void reset_timer_masked(void)
{
	/* reset time, capture current incrementer value time */
	lastinc = get_counter();
	timestamp = 0;		/* start "advancing" time stamp from 0 */
	return;
}

ulong get_timer_masked(void)
{
	/* current counter value */
	ulong now = get_counter();
	ulong buf = (now - lastinc) / (IOCLK / CONFIG_SYS_HZ);

	if (buf) {
		if (now >= lastinc) {	/* normal mode (non roll) */
			/* move stamp fordward with absoulte diff ticks */
			timestamp += buf;
		} else {		/* we have rollover of incrementer */
			timestamp += ((TIMER_LOAD_VAL - lastinc + now)
				      / (IOCLK / CONFIG_SYS_HZ));
		}
		lastinc = now;
	}
	return timestamp;
}

unsigned long long get_ticks(void)
{
	return get_timer(0);
}

ulong get_tbclk (void)
{
	return CONFIG_SYS_HZ;;
}
