#!/bin/sh
set -e

TOOLCHAIN=${ARM_TOOLCHAIN_PREFIX}
OBJCOPY="${TOOLCHAIN}-objcopy"

KNLCFG="${MAKETOP}/boot/kernelconfig"
LINUX_BIN_SRC="${MAKETOP}/boot/vmlinux"

UBOOT_DIR=`dirname $0`
cd ${UBOOT_DIR}

BUILD_DIR=`pwd`
INSTALL_DIR="${MAKETOP}/boot"

UBOOT_KNLAUTOCONF="include/knl_autoconf.h"

BOARD_NAME="MN2WSXXXX_ref"

remove_uboot_knl_autoconf()
{
    rm -f ${UBOOT_KNLAUTOCONF}
}

import_linux_autoconf()
{
	PICK_CONFIGS="CONFIG_UNIPHIER_L2CACHE_ENABLE		\
				  CONFIG_MTD							\
				  CONFIG_MTD_NAND_MN2WS_BB				\
				  CONFIG_KERNEL_RAM_BASE_ADDRESS		\
				  CONFIG_MN2WS_EXT_MEM_LAYOUT			\
				  CONFIG_MODULES_CUSTOM_VADDR			\
				  CONFIG_ARM_ERRATA_764369				\
				  CONFIG_MTD_NAND_MN2WS_CHIP_BANK		\
				  CONFIG_MTD_NAND_MN2WS_CHIP_SIZE_GBIT	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_BLOCKSIZE	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_PAGESIZE	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_OOBSIZE	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NCDWR	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NCAAD	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NRW	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NRDCP	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NRWLP	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NRWHP	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NCES	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_NRR	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_CA_BYTES	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_PA_BYTES	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_AREA_BLOCKS_BOOT_BANK0	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_AREA_BLOCKS_ALT_BANK0	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_AREA_BLOCKS_ALT_BANK1	\
				  CONFIG_MTD_NAND_MN2WS_CORRECT_ERROR_BITS	\
				  CONFIG_MTD_NAND_MN2WS_CHIP_MT29F8G08ADBDAH4 \
				  CONFIG_NANDBOOT_BANKCHOICE	\
				  CONFIG_MMC	\
				  CONFIG_MMC_UNIPHIER	\
				  CONFIG_KERNEL_RAM_END_ADDRESS0	\
				  CONFIG_ENABLE_SECURE_BOOT	\
				  CONFIG_ENABLE_SECURE_EXEC	\
				  CONFIG_RECORD_BOOTTIME \
				  CONFIG_MACH_TYPE_NUM	\
				  CONFIG_PROC_MN2WS0220	\
				  CONFIG_PROC_MN2WS0230	\
				  CONFIG_PROC_MN2WS0251	\
				  CONFIG_PROC_MN2WS0270	\
				  CONFIG_PROC_MN2WS0300	\
				  CONFIG_PROC_MN2WS0310	\
				  CONFIG_PROC_MN2WS0320"

	echo "#define KNL_AUTOCONF_H" > ${UBOOT_KNLAUTOCONF}
	while read LINE; do
		CONFIG=`echo "${LINE}" | sed -n -e "s/^\([^=]*\)=.*/\1/p"`
		case ${CONFIG} in
			"CONFIG_MACH_MN2WS0220_REF")		BOARD_NAME="MN2WS0220_ref";;
			"CONFIG_MACH_MN2WS0230_REF")		BOARD_NAME="MN2WS0230_ref";;
			"CONFIG_MACH_MN2WS0251_REF")		BOARD_NAME="MN2WS0251_ref";;
			"CONFIG_MACH_MN2WS0270_REF")		BOARD_NAME="MN2WS0270_ref";;
			"CONFIG_MACH_MN2WS0310_REF")		BOARD_NAME="MN2WS0310_ref";;
		esac
		for PICK_CONFIG in ${PICK_CONFIGS}; do
		if [ "${CONFIG}" = "${PICK_CONFIG}" ]; then
			echo "#define ${LINE}" | sed -e "s/=y$/ 1/" -e "s/=/ /" \
				>> ${UBOOT_KNLAUTOCONF}
		fi
		done
	done < ${KNLCFG}
}

link_board_depend_header()
{
	here=`pwd`
	cd ${BUILD_DIR}/include
	if [ -d ../board/panasonic/${BOARD_NAME}/include ];then
		ln -s ../board/panasonic/${BOARD_NAME}/include board
	else
		echo "No board-dependent header directory linked."
	fi
	cd $here
}

unlink_board_depend_header()
{
	here=`pwd`
	cd ${BUILD_DIR}/include
	if [ -L board ];then
		unlink board
	fi
	cd $here
}

if [ $# = 1 -a "$1" = "clean" ]; then
  unlink_board_depend_header
  make BUILD_DIR="${BUILD_DIR}" clean
elif [ $# = 1 -a "$1" = "distclean" ]; then
  unlink_board_depend_header
  make BUILD_DIR="${BUILD_DIR}" distclean
  remove_uboot_knl_autoconf
else
  import_linux_autoconf
  unlink_board_depend_header
  link_board_depend_header
  make BUILD_DIR="${BUILD_DIR}" ${BOARD_NAME}_config
  make BUILD_DIR="${BUILD_DIR}"
  mkdir -p ${INSTALL_DIR}
  cp -v -p u-boot.bin ${INSTALL_DIR}
  cp -v -p include/autoconf.mk ${INSTALL_DIR}/ubootconfig
fi

RET=$?
#echo "${RET}"
exit ${RET}
