/*
 * Configuation settings for MN2WS0310_ref
 *
 * Copyright (C) Panasonic Corporation
 * All Rights Reserved.
 *
 * SPDX-License-Identifier:	GPL-2.0+
 */

#ifndef __MN2WS0310_ref_H
#define __MN2WS0310_ref_H

#include <knl_autoconf.h>

/*-----------------------------------------------------------------------
 * CPU Type		(no use this define)
 *----------------------------------------------------------------------*/
#define CONFIG_UNIPHIER
/*-----------------------------------------------------------------------
 * Board Type
 *----------------------------------------------------------------------*/
#define CONFIG_MN2WS0310_ref
/*-----------------------------------------------------------------------
 * Cache Setting
 *----------------------------------------------------------------------*/
//#define CONFIG_SYS_ICACHE_OFF
//#define CONFIG_SYS_DCACHE_OFF

/*-----------------------------------------------------------------------
 * Memory Size & Mapping
 *----------------------------------------------------------------------*/
#define CONFIG_NR_DRAM_BANKS		2
#define PHYS_SDRAM_1				0x80000000
#define PHYS_SDRAM_1_SIZE			0x40000000
#define PHYS_SDRAM_2				(0x80000000 + 0x40000000)
#define PHYS_SDRAM_2_SIZE			0x40000000

#define CONFIG_SYS_SDRAM_BASE		PHYS_SDRAM_1
#define CONFIG_SYS_SDRAM_SIZE		PHYS_SDRAM_1_SIZE

#define CONFIG_SYS_TEXT_BASE		0x95000000

#define CONFIG_SYS_INIT_RAM_ADDR	0x95100000
#define CONFIG_SYS_INIT_RAM_SIZE	0x4000
#define CONFIG_SYS_INIT_SP_ADDR		(CONFIG_SYS_INIT_RAM_ADDR + \
					 CONFIG_SYS_INIT_RAM_SIZE - \
					 GENERATED_GBL_DATA_SIZE)

#define CONFIG_SYS_MALLOC_LEN		(1024 * 1024)

/* default load address */
#define CONFIG_SYS_LOAD_ADDR		0x8a000000

#define CONFIG_SYS_MEMTEST_START	(CONFIG_SYS_SDRAM_BASE/* + 0x00100000*/)
#define CONFIG_SYS_MEMTEST_END		(CONFIG_SYS_MEMTEST_START + CONFIG_SYS_SDRAM_SIZE/*0x00100000*/)

/* start address of UNCACHE AREA */
#define CONFIG_SYS_DUMMY_UNCACHE_BASE	0xe0000000
#define CONFIG_SYS_TARGETSERIES_dtv_sh_2nd
#if defined(CONFIG_SYS_TARGETSERIES_dtv_sni_fhd)
#define CONFIG_SYS_MAINROM_BASE		0x9b000000
#define CONFIG_SYS_UNCACHE_BASE		0x9b800000
#else	/* !defined(CONFIG_SYS_TARGETSERIES_dtv_sni_fhd) */
#define CONFIG_SYS_MAINROM_BASE		0xfb000000
#define CONFIG_SYS_UNCACHE_BASE		0xfb800000
#endif	/* !defined(CONFIG_SYS_TARGETSERIES_dtv_sni_fhd) */
#define CONFIG_SYS_UNCACHE_SIZE		0x00100000

/* start of L2 cache registers */
#define CONFIG_SYS_L2C_BASE			0x50000000	/* P.A. */

/* software update flag load address */
#if defined(CONFIG_NANDBOOT_BANKCHOICE)
#define FWBANK_BOOTFLAG_OFFSET		(0x80000000 + 0x0DA0A000)
#ifndef PANA_SAMPLE_BOARD
#define SWUPFLAG_MAGIC				(0xCAFE0000)
#endif
#endif

/*-----------------------------------------------------------------------
 * first step setting
 *----------------------------------------------------------------------*/
#if defined(CONFIG_MODULES_CUSTOM_VADDR)
#define LINUX_BOOT_PARAM_ADDR		(CONFIG_KERNEL_RAM_BASE_ADDRESS+0x21203000)
#elif defined(CONFIG_MN2WS_EXT_MEM_LAYOUT)
#define LINUX_BOOT_PARAM_ADDR		(CONFIG_KERNEL_RAM_BASE_ADDRESS+0x20003000)
#else
#define LINUX_BOOT_PARAM_ADDR		(CONFIG_KERNEL_RAM_BASE_ADDRESS+0x3000)
#endif
#ifndef CONFIG_UNIPHIER_L2CACHE_ENABLE
#define CONFIG_SYS_L2CACHE_OFF		1
#endif
//#define CONFIG_SKIP_LOWLEVEL_INIT	1
//#define CONFIG_SYS_SKIP_ARM_RELOCATION	1
#define CONFIG_CMDLINE_TAG		1

/*-----------------------------------------------------------------------
 * Display CPU and Board information
 *----------------------------------------------------------------------*/
//#define CONFIG_DISPLAY_CPUINFO		1
//#define CONFIG_DISPLAY_BOARDINFO	1

/*-----------------------------------------------------------------------
 * UNIPHIER Serial Configuration
 *----------------------------------------------------------------------*/
#define CONFIG_UNIPHIER_SERIAL
#define CONFIG_UNIPHIER_SERIAL_HIGH_SPEED
//#define CONFIG_SC_UART

/*-----------------------------------------------------------------------
 * serial console configuration
 *----------------------------------------------------------------------*/
#define CONFIG_BAUDRATE			115200
#define CONFIG_NOREPEAT_COMMAND

/*-----------------------------------------------------------------------
 * Network configuration
 *----------------------------------------------------------------------*/
#define CONFIG_NET_MULTI
#define CONFIG_TFTP_BLOCKSIZE		1024
#define CONFIG_SYS_MAC_EEPROM		0	/* 1:MAC address recorded in EEPROM */

/*-----------------------------------------------------------------------
 * Ethernet Configuration
 *----------------------------------------------------------------------*/
#define CONFIG_UNIPHIER_AVEV4
#define CONFIG_UNIPHIER_ETHERNET
#define CONFIG_UNIPHIER_ETHERNET_BASE	0x65000000
#define CONFIG_UNIPHIER_ETHERNET_NC_OFF	0x00000000
#define CONFIG_RMII			1
#if CONFIG_RMII
#define CONFIG_RSTCTL_REG_OFFSET	0x8028
#endif

//#define CONFIG_SMC911X
//#define CONFIG_SMC911X_32_BIT

/*-----------------------------------------------------------------------
 * Support card related
 *----------------------------------------------------------------------*/
#if defined(CONFIG_SC_UART) || defined(CONFIG_SMC911X)
#define CONFIG_BOARD_EARLY_INIT_F	1	/* call board_early_init_f()	*/
#define SUPPORT_CARD_BASE_SRAMBOOT	0x00000000
#define SUPPORT_CARD_BASE_NANDBOOT	0x02000000
#ifdef CONFIG_SMC911X
#define CONFIG_SMC911X_BASE		(support_card_base +0x01F00000)
#endif
#endif

/*-----------------------------------------------------------------------
 * Serial Configuration
 *----------------------------------------------------------------------*/
#define USE_UART	2

#ifdef CONFIG_SC_UART
#define CONFIG_UNIPHIER_SERIAL_BASE	(support_card_base+ 0x01FB0000)
#else
#if USE_UART==0
#define CONFIG_UNIPHIER_SERIAL_BASE	0x54006800	/* Use UART1 */
#elif USE_UART==1
#define CONFIG_UNIPHIER_SERIAL_BASE	0x54006900	/* Use UART1 */
#elif USE_UART==2
#define CONFIG_UNIPHIER_SERIAL_BASE	0x54006A00	/* Use UART2 */
#endif
#endif

/*-----------------------------------------------------------------------
 * FLASH related
 *----------------------------------------------------------------------*/
#if 0
#define CONFIG_MTD_DEBUG
#define CONFIG_MTD_DEBUG_VERBOSE	7
#endif
#ifdef CONFIG_MTD
#define CONFIG_MTD_DEVICE
#endif
#define CONFIG_SYS_NO_FLASH
//#define CONFIG_SYS_FLASH_BASE
//#define CONFIG_SYS_FLASH_SIZE

/*-----------------------------------------------------------------------
 * NAND-FLASH related
 *----------------------------------------------------------------------*/
#ifdef CONFIG_MTD
#define CONFIG_SYS_MAX_NAND_DEVICE		1
#define CONFIG_NAND_GPBC
#define CONFIG_SYS_NAND_BASE			0x68000000
#define CONFIG_SYS_NAND_IOREMAP_SIZE		0x00000020
#define CONFIG_SYS_NAND_REG_BASE		0x68100000
#define CONFIG_SYS_NAND_REG_IOREMAP_BASE	0x00001000
#define CONFIG_SYS_NAND_REST_BASE		0x61842000
#define CONFIG_SYS_NAND_REST			0x00000004
#define CONFIG_MTD_NAND_MN2WS_GPBC_DMA
#ifdef CONFIG_NAND_GPBC
#define CONFIG_MTD_NAND_MN2WS_GPBC
#endif
#ifdef CONFIG_MTD_NAND_MN2WS_GPBC_DMA
#define CONFIG_MTD_NAND_MN2WS_GPBC_CDMA_READ
#endif
#ifdef  CONFIG_MTD_NAND_MN2WS_GPBC_CDMA_READ
#define CONFIG_NAND_UCAREA_ADDR			CONFIG_SYS_UNCACHE_BASE
#endif

/********** ORDER LIST *********/
#define NAND_MN2WS_AREA_ORDER_BDAM	0	/* BOOT, DATA, ALT,  BBM   */
#define NAND_MN2WS_AREA_ORDER_BDMA	1	/* BOOT, DATA, BBM,  ALT   */
#define NAND_MN2WS_AREA_ORDER_BADM	2	/* BOOT, ALT,  DATA, BBM   */
#define NAND_MN2WS_AREA_ORDER_BAMD	3	/* BOOT, ALT,  BBM,  DATA  */
#define NAND_MN2WS_AREA_ORDER_BMDA	4	/* BOOT, BBM,  DATA, ALT   */
#define NAND_MN2WS_AREA_ORDER_BMAD	5	/* BOOT, BBM,  ALT,  DATA  */
/******************************/
/* Area order: select from "ORDER LIST" */
#define CONFIG_SYS_NAND_AREA_ORDER	NAND_MN2WS_AREA_ORDER_BDAM

//#define CONFIG_SYS_NAND_SELECT_DEVICE
//#define CONFIG_JFFS2_NAND
#define CONFIG_MTD_NAND_MN2WS_USE_BBT_FLAG

/*
 * For NAND booting the environment is embedded in the U-Boot image. Please take
 * look at the file board/amcc/canyonlands/u-boot-nand.lds for details.
 */
#define CONFIG_SYS_NAND_BLOCK_SIZE	(CONFIG_MTD_NAND_MN2WS_CHIP_BLOCKSIZE)
#define CONFIG_SYS_NAND_PAGE_SIZE	(CONFIG_MTD_NAND_MN2WS_CHIP_PAGESIZE)
#define CONFIG_SYS_NAND_U_BOOT_OFFS	(0x01800000)
#define CONFIG_SYS_NAND_U_BOOT_SIZE	(CONFIG_SYS_NAND_BLOCK_SIZE * 1)

#endif /* CONFIG_MTD */

/* MMC related */
//#define CONFIG_MMC
#ifdef CONFIG_MMC
//#define CONFIG_ENABLE_MMC_CH0
#define CONFIG_ENABLE_EMMC_CH1
#define CONFIG_EMMC_CTL_BASEADDR	0x59810200
#define CONFIG_EMMC_IF_BASEADDR		0x5a000000
#define CONFIG_MMC_CTL_BASEADDR		0x59810000
#define CONFIG_MMC_IF_BASEADDR		0x5a400000

#define CONFIG_GENERIC_MMC
#define CONFIG_UNIPHIER_MMC
#define CONFIG_DOS_PARTITION
#define CONFIG_SUPPORT_EMMC_BOOT
//#define CONFIG_MMC_UNIPHIER_DMA_DISABLE
//#define CONFIG_SUPPORT_MMC_WRITE_PROTECT
//#define CONFIG_MMC_TRACE
#endif	/* CONFIG_MMC */

//#define CONFIG_ENV_IS_NOWHERE
#ifdef CONFIG_MMC
#define CONFIG_ENV_IS_IN_MMC
#else
#define CONFIG_ENV_IS_IN_NAND
#endif

#ifdef CONFIG_ENV_IS_IN_NAND
#define CONFIG_ENV_SIZE			(CONFIG_SYS_NAND_BLOCK_SIZE * 1)
#define CONFIG_ENV_OFFSET		(0x01500000)
#endif

#ifdef CONFIG_ENV_IS_IN_MMC
#define CONFIG_SYS_MMC_ENV_DEV		0
#define CONFIG_ENV_SIZE			0x1000
#define CONFIG_ENV_OFFSET		(0x01180000)
#endif

#ifdef CONFIG_MMC
#define KERNEL_START			0x0000b800
#define ROOTFS_START			0x001fffc0

#else /* CONFIG_MMC */
#if defined(CONFIG_NANDBOOT_BANKCHOICE)
#define NAND_BANK0_START		0x017c0000
#define NAND_BANK1_START		0x07040000
#define NAND_VERUP_START		0x00200000
#endif
#define NAND_KERNEL_START		0x01d40000
#define NAND_ROOTFS_START		0x02340000
#define NAND_VKERNEL_START  0x00780000
#endif /* CONFIG_MMC */

/*-----------------------------------------------------------------------
 * Possible commands
 *----------------------------------------------------------------------*/
//#define CONFIG_CMD_BDI		/* bdinfo			*/
#define CONFIG_CMD_BOOTD	/* bootd			*/
//#define CONFIG_CMD_CONSOLE	/* coninfo			*/
#define CONFIG_CMD_ECHO		/* echo arguments		*/
//#define CONFIG_CMD_EDITENV	/* editenv			*/
//#define CONFIG_CMD_IMI		/* iminfo			*/
//#define CONFIG_CMD_ITEST	/* Integer (and string) test	*/
#ifdef CONFIG_MTD
#define CONFIG_CMD_NAND		/* NAND flash suppport */
#endif
//#define CONFIG_CMD_LOADB	/* loadb			*/
//#define CONFIG_CMD_LOADS	/* loads			*/
#define CONFIG_CMD_MEMORY	/* md mm nm mw cp cmp crc base loop mtest */
//#define CONFIG_CMD_MISC		/* Misc functions like sleep etc*/
#define CONFIG_CMD_NET		/* bootp, tftpboot, rarpboot	*/
//#define CONFIG_CMD_NFS		/* NFS support			*/
#define CONFIG_CMD_RUN		/* run command in env variable	*/
#define CONFIG_CMD_SAVEENV	/* saveenv			*/
#define CONFIG_CMD_SOURCE	/* "source" command support	*/

//#define CONFIG_CMD_JFFS2	/* JFFS2 Support		*/
//#define CONFIG_CMD_PING
#ifdef CONFIG_MMC
#define CONFIG_CMD_MMC		/* MMC support			*/
#define CONFIG_CMD_FAT
#define CONFIG_CMD_EXT4
#define CONFIG_CMD_UNZIP
#define CONFIG_CMD_PART
#define CONFIG_PARTITION_UUIDS
#endif

/*-----------------------------------------------------------------------
 * Environment Variables
 *----------------------------------------------------------------------*/
#define CONFIG_BOOTDELAY		0
#define CONFIG_ZERO_BOOTDELAY_CHECK	/* check for keypress on bootdelay==0 */
#define CONFIG_AUTOBOOT_KEYED	1
#define CONFIG_AUTOBOOT_PROMPT	\
	"Press SPACE to abort autoboot in %d seconds\n", bootdelay
#define CONFIG_AUTOBOOT_DELAY_STR	"d"
#define CONFIG_AUTOBOOT_STOP_STR	" "

#define CONFIG_BOOTFILE		"uImage"

#define CONFIG_CMDLINE_EDITING		/* add command line history	*/

#ifdef CONFIG_MMC
#define BOOTCOMMAND(kernel_ram)                             \
  "mmc read " #kernel_ram " $kerneloffset 0x100 && "        \
  "imglen_mmc " #kernel_ram " kernelsize && "               \
  "mmc read " #kernel_ram " $kerneloffset $kernelsize && "  \
  "bootm " #kernel_ram
#define BOOTCOMMAND_SECURE(kernel_ram, rootfs_ram)          \
  "mmc read " #kernel_ram " $kerneloffset 0x100 && "        \
  "imglen_mmc " #kernel_ram " kernelsize && "               \
  "mmc read " #kernel_ram " $kerneloffset $kernelsize && "  \
  "mmc read " #rootfs_ram " $rootfsoffset 0x100 && "        \
  "rootfslen_mmc " #rootfs_ram " rootfssize && "            \
  "mmc read " #rootfs_ram " $rootfsoffset $rootfssize && "  \
  "bootm " #kernel_ram

#else /* CONFIG_MMC */
#define BOOTCOMMAND(kernel_ram)                             \
  "nand read " #kernel_ram " $kerneloffset 0x100 && "       \
  "imglen " #kernel_ram " kernelsize && "                   \
  "nand read " #kernel_ram " $kerneloffset $kernelsize && " \
  "bootm " #kernel_ram
#define BOOTCOMMAND_SECURE(kernel_ram, rootfs_ram)          \
  "nand read " #kernel_ram " $kerneloffset 0x100 && "       \
  "imglen " #kernel_ram " kernelsize && "                   \
  "nand read " #kernel_ram " $kerneloffset $kernelsize && " \
  "nand read " #rootfs_ram " $rootfsoffset 0x100 && "       \
  "squashlen " #rootfs_ram " rootfssize && "                \
  "nand read " #rootfs_ram " $rootfsoffset $rootfssize && " \
  "bootm " #kernel_ram

#endif /* CONFIG_MMC */

#if defined(CONFIG_ENABLE_SECURE_EXEC)
#define CONFIG_BOOTCOMMAND      BOOTCOMMAND_SECURE(0x8a000000, 0xA0000000)
#else
#define CONFIG_BOOTCOMMAND      BOOTCOMMAND(0x8a000000)
#endif

#ifdef CONFIG_MMC
#define CONFIG_BOOTARGS	"root=/dev/mmcblk0p1 rootfstype=ext4 rootdelay=1 rw  mem=165M@0x8DB00000 mem=478M@0xD6D00000 console=ttyS2,115200 nfsroot= ip=192.168.1.10:192.168.1.1:192.168.1.1:255.255.255.0:target:eth0:on user_debug=0x1f debug init=/sbin/init"
#define CONFIG_ROOTDEV	/dev/mmcblk0p1
#else /* CONFIG_MMC */
#define CONFIG_BOOTARGS	"root=/dev/mtdblock13 rootfstype=squashfs rw  mem=165M@0x8DB00000 mem=478M@0xD6D00000 console=ttyS2,115200 nfsroot= ip=192.168.1.10:192.168.1.1:192.168.1.1:255.255.255.0:target:eth0:on user_debug=0x1f debug init=/sbin/init"
#ifndef PANA_SAMPLE_BOARD
#define CONFIG_BOOTARGS_USB       "console=ttyS2,115200 mem=165M@0x8DB00000 mem=478M@0xD6D00000 user_debug=0x1f rdinit=/sbin/verup_usb"
#define CONFIG_BOOTARGS_PCC       "console=ttyS2,115200 mem=165M@0x8DB00000 mem=478M@0xD6D00000 user_debug=0x1f rdinit=/sbin/verup_pcc"
#define CONFIG_BOOTARGS_BANKA     "console=ttyS2,115200 mem=165M@0x8DB00000 mem=478M@0xD6D00000 user_debug=0x1f root=/dev/mtdblock13 rootfstype=squashfs rw lpj=11870208 init=/sbin/init"
#define CONFIG_BOOTARGS_BANKB     "console=ttyS2,115200 mem=165M@0x8DB00000 mem=478M@0xD6D00000 user_debug=0x1f root=/dev/mtdblock19 rootfstype=squashfs rw lpj=11870208 init=/sbin/init"
#endif
#define CONFIG_ROOTDEV	/dev/mtdblock13
#endif /* CONFIG_MMC */

#define CONFIG_MEM	" mem=165M@0x8DB00000 mem=478M@0xD6D00000"

#ifdef CONFIG_MMC
#define CONFIG_RELOAD		"setenv bootargs root=${rootdev} rootfstype=ext4 rootdelay=1 rw ${mem} console=ttyS2,115200 ip=${ipaddr}:${nfsserverip}:${gatewayip}:${netmask}:${hostname}:eth0:on user_debug=0x1f debug init=/sbin/init"
#else /* CONFIG_MMC */
//#define CONFIG_RELOAD		"setenv bootargs root=${rootdev} rootfstype=squashfs rw ${mem} console=ttyS2,115200 ip=${ipaddr}:${nfsserverip}:${gatewayip}:${netmask}:${hostname}:eth0:on user_debug=0x1f debug init=/sbin/init"
#define CONFIG_RELOAD		"setenv bootargs root=${rootdev} rootfstype=squashfs rw lpj=11870208 ${mem} console=ttyS2,115200 ip=${ipaddr}:${nfsserverip}:${gatewayip}:${netmask}:${hostname}:eth0:on user_debug=0x1f debug init=/sbin/init"
#endif /* CONFIG_MMC */

#define CONFIG_RELOAD_NFS	"setenv bootargs root=/dev/nfs rw ${mem} console=ttyS2,115200 nfsroot=${nfsserverip}:${rootpath} ip=${ipaddr}:${nfsserverip}:${gatewayip}:${netmask}:${hostname}:eth0:on user_debug=0x1f debug init=/sbin/init"

#define	CONFIG_EXTRA_ENV_SETTINGS	\
"appxip=y\0"						\
"autoboot=y\0"

/*
 * Network Configuration
 */
#define CONFIG_SERVERIP			192.168.1.1
#define CONFIG_IPADDR			192.168.1.10
#define CONFIG_GATEWAYIP		192.168.1.1
#define CONFIG_NETMASK			255.255.255.0
#define CONFIG_NFSSERVERIP		192.168.1.1
#define CONFIG_ROOTPATH			
#define CONFIG_HOSTNAME			target
#define CONFIG_TARGET			

/* #endif */
/*-----------------------------------------------------------------------
 * Miscellaneous Configuration Settings
 *----------------------------------------------------------------------*/
//#define CONFIG_SYS_LONGHELP		/* undef to save memory */
#define CONFIG_SYS_PROMPT		"U-Boot> "
#define CONFIG_CMDLINE_EDITING		/* add command line history	*/
#define CONFIG_SYS_HUSH_PARSER		/* use "hush" command parser */
#define CONFIG_SYS_PROMPT_HUSH_PS2	"> "
#define CONFIG_SYS_CBSIZE		1024	/* Console I/O Buffer Size */
/* Print Buffer Size */
#define CONFIG_SYS_PBSIZE		(CONFIG_SYS_CBSIZE + sizeof(CONFIG_SYS_PROMPT) + 16)
#define CONFIG_SYS_MAXARGS		16	/* max number of command */
#define CONFIG_SYS_64BIT_VSPRINTF
/* Boot Argument Buffer Size */
#define CONFIG_SYS_BARGSIZE		(CONFIG_SYS_CBSIZE)
/* List of legal baudrate settings for this board */
#define CONFIG_CONS_INDEX		1
#ifdef CONFIG_UNIPHIER_SERIAL_HIGH_SPEED
#define CONFIG_SYS_BAUDRATE_TABLE	{ 115200, 230400, 460800 }
#else
#define CONFIG_SYS_BAUDRATE_TABLE	{ 9600, 19200, 38400, 57600, 115200 }
#endif	/* CONFIG_UNIPHIER_SERIAL_HIGH_SPEED */
/* Increase max gunzip size */
#define CONFIG_SYS_BOOTM_LEN	(32 << 20)
/* Boot params (bootargs) length */
#define CONFIG_SYS_BOOTPARAMS_LEN	1024

/* System Clock */
#define CONFIG_SYS_HZ			1000

/* compression format (Remove definition, If you don't need) */
#define CONFIG_LZO
//#define CONFIG_LZMA
/* compression format (select CONFIG_GZIP/CONFIG_LZO / CONFIG_LZMA) */
// for CommonPF #define CONFIG_KERNEL_COMPRESS CONFIG_LZO
#define CONFIG_KERNEL_COMPRESS CONFIG_GZIP

#define CONFIG_SILENT_CONSOLE
#define CONFIG_DISABLE_CONSOLE
#define CONFIG_SILENT			on

#endif /* __MN2WS0310_ref_H */
